.. _sec-installation:

============
Installation
============

To install ``htsget``, simply run::

    $ pip install htsget

If you wish to install ``htsget`` into a your local Python installation, use::

    $ pip install htsget --user

However, you will need to ensure that the local binary directory (usually something
like ``$HOME/.local/bin``) is in your PATH.


